#ifndef __servlist_h
#define __servlist_h

@extern void server_list_menu (void);

#endif//__servlist_h
